| autoplot.hspt_n | R Documentation |
Plot the output produced by hotspot_count with reasonable
default values.
## S3 method for class 'hspt_n'
autoplot(object, ...)
## S3 method for class 'hspt_n'
autolayer(object, ...)
object |
An object with the class |
... |
further arguments passed to |
A ggplot object or layer that can be used as
part of a ggplot stack.
autoplot returns a ggplot object, meaning you can further
control the appearance of the plot by adding calls to further ggplot2
functions.
autolayer(hspt_n): Create a ggplot layer of grid counts
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.