Learn R Programming

sfhotspot (version 1.0.0)

hotspot_clip: Extract points inside polygon

Description

Extract points inside polygon

Usage

hotspot_clip(data, boundary, quiet = FALSE, ...)

Value

an SF data frame containing those points that are covered by the polygons.

Arguments

data

sf data frame containing points.

boundary

sf data frame containing polygons.

quiet

if set to TRUE, messages reporting the values of any parameters set automatically will be suppressed. The default is FALSE.

...

Further arguments passed to st_intersection.

Details

This function is a wrapper around st_intersection that performs some additional checks and reports useful information.