Create either a rectangular or hexagonal two-dimensional grid
hotspot_grid(data, cell_size = NULL, grid_type = "rect", quiet = FALSE, ...)A simple features tibble containing polygons representing grid cells.
The grid will be based on the convex hull of data, expanded by a
buffer of cell_size / 2 to ensure all the points in data fall
within the resulting grid.
sf data frame.
numeric value specifying the size of each equally
spaced grid cell, using the same units (metres, degrees, etc.) as used in
the sf data frame given in the data argument. If this
argument is NULL (the default), the cell size will be calculated
automatically (see Details).
character specifying whether the grid should be made
up of squares ("rect", the default) or hexagons ("hex").
if set to TRUE, messages reporting the values of any
parameters set automatically will be suppressed. The default is
FALSE.
Further arguments passed to link[sf]{st_make_grid}.