Learn R Programming

sfhotspot (version 1.0.0)

memphis_population: Populations of census blocks in Memphis in 2020

Description

A dataset containing records of populations associated with the centroids of census blocks in Memphis, Tennessee, in 2020.

Usage

memphis_population

Arguments

Format

A simple-features tibble with 10,393 rows and three variables:

geoid

the census GEOID for each block

population

the number of people residing in each block

geometry

the co-ordinates of the centroid of each block, stored in simple-features point format