Plot the output produced by hotspot_classify with reasonable
default values.
# S3 method for hspt_c
autoplot(object, ...)A ggplot object.
This function returns a ggplot object, meaning you can further control
the appearance of the plot by adding calls to further ggplot2
functions.
An object with the class hspt_c, e.g. as produced by
hotspot_classify.
Currently ignored, but may be used for further options in future.