Plot the output produced by hotspot_change with reasonable
default values.
# S3 method for hspt_d
autoplot(object, ...)# S3 method for hspt_d
autolayer(object, ...)
A ggplot object.
This function returns a ggplot object, meaning you can further control
the appearance of the plot by adding calls to further ggplot2
functions.
An object with the class hspt_d, e.g. as produced by
hotspot_change.
Currently ignored, but may be used for further options in future.
autolayer(hspt_d): Create a ggplot layer of change in grid counts