Plot the output produced by hotspot_kde with reasonable
default values.
# S3 method for hspt_k
autoplot(object, ...)# S3 method for hspt_k
autolayer(object, ...)
A ggplot object or layer that can be used as
part of a ggplot stack.
autoplot returns a ggplot object, meaning you can further
control the appearance of the plot by adding calls to further ggplot2
functions.
An object with the class hspt_k, e.g. as produced by
hotspot_kde.
further arguments passed to geom_sf, e.g.
alpha.
autolayer(hspt_k): Create a ggplot layer of kernel-density values