Learn R Programming

sfhotspot (version 1.0.0)

autoplot.hspt_n: Plot map of grid counts

Description

Plot the output produced by hotspot_count with reasonable default values.

Usage

# S3 method for hspt_n
autoplot(object, ...)

# S3 method for hspt_n autolayer(object, ...)

Value

A ggplot object or layer that can be used as part of a ggplot stack.

autoplot returns a ggplot object, meaning you can further control the appearance of the plot by adding calls to further ggplot2

functions.

Arguments

object

An object with the class hspt_n, e.g. as produced by hotspot_count.

...

further arguments passed to geom_sf, e.g. alpha.

Functions

  • autolayer(hspt_n): Create a ggplot layer of grid counts