A dataset containing records of populations associated with the centroids of census blocks in Memphis, Tennessee, in 2020.
memphis_populationA simple-features tibble with 10,393 rows and three variables:
the census GEOID for each block
the number of people residing in each block
the co-ordinates of the centroid of each block, stored in simple-features point format